@@ -11,18 +11,16 @@ class DevGet(FiggyTest):
         super().__init__(pexpect.spawn(f'{CLI_NAME} config {Utils.get_first(get)} --env {DEFAULT_ENV} '
                                        f'--skip-upgrade {extra_args}',
                                        timeout=10, encoding='utf-8'), extra_args=extra_args)
-        self._child.delayafterread = .01
-        self._child.delaybeforesend = .5
 
     def run(self):
         self.step(f"Testing GET for {param_1}")
         self.get(param_1, param_1_val, get_more=False)
 
     def get(self, key, value, get_more=False, expect_missing=False, no_decrypt=False):
-        self.expect('.*PS Name*')
+        self.expect('.*PS Name.*')
         self.sendline(key)
         if expect_missing:
-            self.expect(f'.*Invalid PS Name specified..*')
+            self.expect(f'.*Invalid PS Name specified.*')
             print("Missing parameter validated.")
         elif no_decrypt:
             self.expect(f'.*do not have access.*')
