@@ -24,9 +24,11 @@ class DevList(FiggyTest):
         self._setup(1, 3)
         print(f"Testing {CLI_NAME} config {Utils.get_first(list_com)} --env dev")
         print("Waiting for cache population.")
-        time.sleep(45)
+        time.sleep(70)
         child = pexpect.spawn(f'{CLI_NAME} config {Utils.get_first(list_com)} --env {DEFAULT_ENV} '
                               f'--skip-upgrade {self.extra_args}', timeout=10, encoding='utf-8')
+        child.logfile = sys.stdout
+        child.delaybeforesend = .25
         child.expect('.*Please input a namespace prefix.*')
         child.sendline("")
         child.expect('.*Please input a namespace prefix.*')
@@ -46,13 +48,15 @@ class DevList(FiggyTest):
     def successful_list(self):
         self._setup(1, 3)
         print("Waiting for cache population.")
-        time.sleep(45)
+        time.sleep(70)
 
         self.step("Testing successful list.")
         print(f"Testing {CLI_NAME} config {Utils.get_first(list_com)} --env dev")
         child = pexpect.spawn(f'{CLI_NAME} config {Utils.get_first(list_com)} --env {DEFAULT_ENV} '
                               f'--skip-upgrade {self.extra_args}',
                               timeout=10, encoding='utf-8')
+        child.logfile = sys.stdout
+        child.delaybeforesend = .25
 
         child.expect('.*Please input a namespace prefix.*')
         child.sendline(dump_prefix)
